@@ -13,7 +13,7 @@ use HTTP::Date;
 use HTTP::Status qw{ :constants };
 use Test::More 0.96;	# For subtest
 
-our $VERSION = '0.127_01';
+our $VERSION = '0.127_03';
 
 # Set the following to zero if Space Track (or any other SSL host)
 # starts using a certificate that can not be verified.
@@ -380,6 +380,8 @@ EOD
 
 sub spacetrack_skip_no_prompt {
     my $skip;
+    $ENV{SPACETRACK_TEST_LIVE}
+	or plan skip_all => 'SPACETRACK_TEST_LIVE not set';
     defined( $skip = __spacetrack_skip(
 	    envir	=> 1,
 	    no_prompt	=> NO_SPACE_TRACK_ACCOUNT,
